@@ -1,7 +1,8 @@
 import json
-from json import JSONDecodeError
+import os
 import subprocess
-from typing import List, Optional, Tuple
+from json import JSONDecodeError
+from typing import List, Optional, Tuple, Dict
 
 from elementary.exceptions.exceptions import DbtCommandError
 from elementary.utils.log import get_logger
@@ -18,11 +19,13 @@ class DbtRunner:
         profiles_dir: str,
         target: Optional[str] = None,
         raise_on_failure: bool = True,
+        dbt_env_vars: Dict[str, str] = None,
     ) -> None:
         self.project_dir = project_dir
         self.profiles_dir = profiles_dir
         self.target = target
         self.raise_on_failure = raise_on_failure
+        self.dbt_env_vars = dbt_env_vars
 
     def _run_command(
         self,
@@ -44,21 +47,20 @@ class DbtRunner:
         if vars:
             json_vars = json.dumps(vars)
             dbt_command.extend(["--vars", json_vars])
+        log_msg = f"Running {' '.join(dbt_command)}"
         if not quiet:
-            logger.info(f"Running {' '.join(dbt_command)} (this might take a while)")
+            logger.info(log_msg)
         else:
-            logger.debug(f"Running {' '.join(dbt_command)}")
+            logger.debug(log_msg)
         try:
             result = subprocess.run(
                 dbt_command,
                 check=self.raise_on_failure,
                 capture_output=(json_output or quiet),
+                env=self._get_command_env(),
             )
         except subprocess.CalledProcessError as err:
-            logger.debug(
-                f"Failed to run dbt command - cmd: {err.cmd}, output: {err.output}, err: {err.stderr}"
-            )
-            raise DbtCommandError(err)
+            raise DbtCommandError(err, command_args)
         output = None
         if json_output:
             output = result.stdout.decode("utf-8")
@@ -159,3 +161,9 @@ class DbtRunner:
             command_args=command_args, vars=vars, quiet=quiet
         )
         return success
+
+    def _get_command_env(self):
+        env = os.environ.copy()
+        if self.dbt_env_vars is not None:
+            env.update(self.dbt_env_vars)
+        return env
